use Test::More;
eval "use Test::Prereq";

my $msg;
if ($@) {
  $msg = 'Test::Prereq required to test dependencies';
} elsif (not $ENV{TEST_AUTHOR}) {
  $msg = 'Author test.  Set $ENV{TEST_AUTHOR} to a true value to run.';
}
plan skip_all => $msg if $msg;
prereq_ok("Testing prerequisites",
	  # include single quotes!
	  [qw('./t/cert.pl' './t/test.pl')]);
